Name "UserMgr.dll Sample Installation Script"

OutFile "usermgr-sample.exe"

#
# Be careful when using these functions, especially the "Remove" and "Delete" commands!!!
#
# Plugin Command Reference:
#
#  UserMgr::CreateAccount USERID PASSWORD COMMENT				; creates a new user account, returns status string
#
#  UserMgr::CreateAccountEx USERID PASSWORD COMMENT FULLNAME USERCOMMENT FLAGS	; creates a new user account, including the Fullname (Shown in the Welcome screen), returns status string
#		where FLAGS can be one or more of the following, seperated by '|':
#			UF_ACCOUNTDISABLE     The user's account is disabled.
#			UF_PASSWD_NOTREQD     No password is required.
#			UF_PASSWD_CANT_CHANGE The user cannot change the password.
#			UF_DONT_EXPIRE_PASSWD The password will never expire on the account.
#
#  UserMgr::BuiltAccountEnv USERID PASSWORD          				; builds the User environment of the user (Registry hive, Documents and settings etc.), returns status string
#  UserMgr::RegLoadUserHive USERID		                  		; loads the User Registry hive in HKEY_USERS\{USERID}, returns status string
#  UserMgr::RegUnLoadUserHive USERID             				; unloads the User Registry hive, returns status string
#  UserMgr::DeleteAccount USERID						; deletes a user account, returns status string
#  UserMgr::AddToGroup USERID GROUPID						; adds a user to a group, returns status string
#  UserMgr::RemoveFromGroup USERID GROUPID					; removes group membership from a user, returns status string
#  UserMgr::AddPrivilege USERID PRIVILEGE					; adds a privilege to the user account, returns status string
#  UserMgr::RemovePrivilege USERID PRIVILEGE					; removes a privilege from an account, returns status string
#  UserMgr::CreateGroup GROUPID COMMENT						; creates a new user group, returns status string
#  UserMgr::DeleteGroup GROUPID							; deletes a user group, returns status string
# 
#  UserMgr::GetUserInfo USERID FIELD						; returns a specific information for the given user-ID
#		where FIELD can be one of the following:
#			EXISTS	returns "OK", if the user exists on the system, otherwise an error is returned (string "ERROR xxxx")
#			NAME		returns the user name
#			FULLNAME	returns the full user name (e.g. firstname surname)
#			HOMEDIR	returns the path to the users home directory
#			COMMENT	returns a comment stored for the user
#			PASSWD_STATUS
#					returns "NEVEREXPIRES" or "CANTCHANGE" 
#
#  UserMgr::SetUserInfo USERID FIELD VALUE						; sets a specific information for the given user-ID
#		where FIELD can be one of the following:
#			NAME		changes the user name
#			PASSWORD	changes the user password (admin rights required)
#			FULLNAME	changes the full user name (e.g. firstname surname)
#			HOMEDIR	changes the path to the users home directory
#			COMMENT	changes the comment stored for the user
#			PASSWD_NEVER_EXPIRES [YES|NO]
#					enables/disables password expiration
# 
#  UserMgr::ChangeUserPassword USERID OLDPASSWORD NEWPASSWORD			; changes the user password (no admin rights required)
# 
#  UserMgr::SetRegKeyAccess  USERID ROOTKEY REGKEY ACCESSMASK		; adds/sets/revokes/denies access rights for registry keys
#		where USERID is the user ID of the account whose rights are altered
#			ROOTKEY can be one of these: HKLM, HKU, HKCU, HKCR
#			REGKEY is the subkey under ROOTKEY
#			ACCESSMASK starts with a '+' to grant rights, "-" to deny rights, "=" to set rights, afterwards the
#				rights can be listed: 'r' for read access, 'w' for write access, 'x' for execute access, 'a' for full access
#	Example:
#		UserMgr::SetRegKeyAccess "myuser" "HKLM" "SYSTEM\CurrentControlSet\Services\Blabla" "=a"
#			grants full access for "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Blabla" to user "myuser"
#			
#	BEWARE: If ACCESSMASK is empty, all of the the users access rights will be removed! This is used to delete an access list entry
#	from a registry key.
#
#	Hint: You can check this by using REGEDT32, which can display/edit the access rights for registry keys!
#
#
# A status string can look like this:
#		"OK"			Function has been completed successfully
#		"ERROR xxxx"	An error occured. Please see MSDN or the LMERR.H file (comes with Visual Studio) to find out about possible error codes
#
#

Function .onInit
        # the plugins dir is automatically deleted when the installer exits
        InitPluginsDir
	
	UserMgr::CreateAccount "myuser" "mypassword" "A test user created by the UserMgr plugin"
	Pop $0
        MessageBox MB_OK "CreateUser Result : $0"

	UserMgr::AddToGroup  "myuser" "Administrators"
	Pop $0
        MessageBox MB_OK "AddToGroup Result : $0"

	UserMgr::SetRegKeyAccess "myuser" "HKLM" "SYSTEM\CurrentControlSet\Services\EventLog\Application\NTP" "=a"
	Pop $0
        MessageBox MB_OK "GrantAccess Result : $0"

	UserMgr::SetRegKeyAccess "myuser" "HKLM" "SYSTEM\CurrentControlSet\Services\EventLog\Application\NTP" "=r"
	Pop $0
        MessageBox MB_OK "RevokeWriteAccess Result : $0"

	UserMgr::SetRegKeyAccess "myuser" "HKLM" "SYSTEM\CurrentControlSet\Services\EventLog\Application\NTP" ""
	Pop $0
        MessageBox MB_OK "RevokeAccess Result : $0"

	UserMgr::DeleteAccount "myuser"
	Pop $0
        MessageBox MB_OK "DeleteUser Result: $0"
        
#####################################################################################################################

	UserMgr::CreateAccountEx "myuserA" "mypassword" "A test user created by the UserMgr plugin" "My User A" "A test user created by the UserMgr plugin" "UF_PASSWD_NOTREQD|UF_DONT_EXPIRE_PASSWD"
	Pop $0
        MessageBox MB_OK "CreateUser Result : $0"

	UserMgr::BuiltAccountEnv "myuserA" "mypassword"
	Pop $0
        MessageBox MB_OK "BuiltAccountEnv Result : $0"

	UserMgr::RegLoadUserHive "myuserA"
	Pop $0
        MessageBox MB_OK "RegLoadUserHive Result : $0"

        WriteRegStr HKEY_USERS "myuserA\Software\My Company\My Software" "String Value" "dead beef"

	UserMgr::RegUnLoadUserHive "myuserA"
	Pop $0
        MessageBox MB_OK "RegUnLoadUserHive Result : $0"

	UserMgr::ChangeUserPassword "myuserA" "mypassword" "mypasswordb"
	Pop $0
        MessageBox MB_OK "ChangeUserPassword Result : $0"

	UserMgr::SetUserInfo "myuserA" "PASSWORD" "mypasswordc"
	Pop $0
        MessageBox MB_OK "SetUserInfo PASSWORD Result : $0"

	UserMgr::DeleteAccount "myuserA"
	Pop $0
        MessageBox MB_OK "DeleteUser Result: $0"


FunctionEnd

Section
SectionEnd